@@ -59,6 +59,8 @@ def parseOUTCAR(OUTCAR_in,foutlog):
             l1=fin.readline()
             l1=fin.readline()
             n1=0
+            if len(pots_list)>0:
+                pots_list=[]
             while n1<sum(natoms):
                 l1=fin.readline()
                 l2=l1.split()[1::2]
@@ -491,17 +493,19 @@ def calcEdefCorrectionVASP():
         rdiff_list=[]
         for ip2,p2 in enumerate(posi_def):
             pdiff1=[p2[0]-p1[0],p2[1]-p1[1],p2[2]-p1[2]]
-            for i1 in range(3):
-                if pdiff1[i1]>0.5:
-                    pdiff1[i1]+=-1.0
-                if pdiff1[i1]<-0.5:
-                    pdiff1[i1]+=1.0
-            pdiff2=[0.0,0.0,0.0]
-            for i1 in range(3):
-                for i2 in range(3):
-                    pdiff2[i2]+=pdiff1[i1]*latt_def[i1][i2]
-            rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
-            rdiff_list.append(rdiff2)
+            rdiff2min=1e10
+            for s0 in [-1,0,1]:
+                for s1 in [-1,0,1]:
+                    for s2 in [-1,0,1]:
+                        pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                        pdiff2=[0.0,0.0,0.0]
+                        for i1 in range(3):
+                            for i2 in range(3):
+                                pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                        rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                        if rdiff2<rdiff2min:
+                            rdiff2min=rdiff2
+            rdiff_list.append(rdiff2min)
         # print(rdiff_list)
         args_rdiff=np.argsort(rdiff_list)
         if min(rdiff_list)>rtol_vac:
@@ -550,13 +554,21 @@ def calcEdefCorrectionVASP():
             p2=def0_posi[id2]
             foutlog.write("    Position_direct("+def0_elems[id2]+") = "+str(p2[0])+" "+str(p2[1])+" "+str(p2[2])+"\n")
             pdiff1=[p2[0]-p1[0],p2[1]-p1[1],p2[2]-p1[2]]
+            rdiff2min=1e10
+            for s0 in [-1,0,1]:
+                for s1 in [-1,0,1]:
+                    for s2 in [-1,0,1]:
+                        pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                        pdiff2=[0.0,0.0,0.0]
+                        for i1 in range(3):
+                            for i2 in range(3):
+                                pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                        rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                        if rdiff2<rdiff2min:
+                            rdiff2min=rdiff2
+                            pdiff3min=copy.copy(pdiff3)
             for i1 in range(3):
-                if pdiff1[i1]>0.5:
-                    pdiff1[i1]-=1.0
-                if pdiff1[i1]<-0.5:
-                    pdiff1[i1]+=1.0
-            for i1 in range(3):
-                averaged_posi[i1]+=pdiff1[i1]
+                averaged_posi[i1]+=pdiff3min[i1]
         for i1 in range(3):
             averaged_posi[i1]=p1[i1]+averaged_posi[i1]/len(def0_elems)
         if len(def0_elems)>1:
@@ -576,19 +588,22 @@ def calcEdefCorrectionVASP():
             rdist.append(0.0)
         else:
             pdiff1=[p2[0]-posi_def0[0],p2[1]-posi_def0[1],p2[2]-posi_def0[2]]
-            for i1 in range(3):
-                if pdiff1[i1]>0.5:
-                    pdiff1[i1]-=1.0
-                if pdiff1[i1]<-0.5:
-                    pdiff1[i1]+=1.0
-            pdiff2=[0.0,0.0,0.0]
-            for i1 in range(3):
-                for i2 in range(3):
-                    pdiff2[i2]+=pdiff1[i1]*latt_def[i1][i2]
-            rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+            rdiff2min=1e10
+            for s0 in [-1,0,1]:
+                for s1 in [-1,0,1]:
+                    for s2 in [-1,0,1]:
+                        pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                        pdiff2=[0.0,0.0,0.0]
+                        for i1 in range(3):
+                            for i2 in range(3):
+                                pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                        rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                        if rdiff2<rdiff2min:
+                            rdiff2min=rdiff2
+                            pdiff3min=copy.copy(pdiff3)
             if rdiff2>rmax:
-                rmax=rdiff2
-            rdist.append(rdiff2)
+                rmax=rdiff2min
+            rdist.append(rdiff2min)
     
 
     #### calc point-charge potential and energy
@@ -637,12 +652,20 @@ def calcEdefCorrectionVASP():
     pot_residual=[]
     for ip1,p1 in enumerate(posi_def):
         pdiff1=np.array([p1[0]-posi_def0[0],p1[1]-posi_def0[1],p1[2]-posi_def0[2]])
-        for i1 in range(3):
-            if pdiff1[i1]>0.5:
-                pdiff1[i1]-=1.0
-            if pdiff1[i1]<-0.5:
-                pdiff1[i1]+=1.0
-        relvect=np.dot(latt_def,pdiff1)
+        rdiff2min=1e10
+        for s0 in [-1,0,1]:
+            for s1 in [-1,0,1]:
+                for s2 in [-1,0,1]:
+                    pdiff3=[pdiff1[0]+s0,pdiff1[1]+s1,pdiff1[2]+s2]
+                    pdiff2=[0.0,0.0,0.0]
+                    for i1 in range(3):
+                        for i2 in range(3):
+                            pdiff2[i2]+=pdiff3[i1]*latt_def[i1][i2]
+                    rdiff2=(pdiff2[0]**2+pdiff2[1]**2+pdiff2[2]**2)**0.5
+                    if rdiff2<rdiff2min:
+                        rdiff2min=rdiff2
+                        pdiff3min=copy.copy(pdiff3)
+        relvect=np.dot(latt_def,pdiff3min)
         r_relvect=np.linalg.norm(relvect)
         if r_relvect<1e-10:
             pot_Model.append(None)
