@@ -403,7 +403,7 @@ class DefectEqSolver:
         print("finished: opt_steady_line_minimization")
         return(cp3,residArray3)
 
-    def opt_chempot_multi(self,func_resid,func_grad,cp0,delta_cp=0.1,fout=None,tol=1e-6,maxiter=1000):
+    def opt_chempot_multi(self,func_resid,func_grad,cp0,delta_cp=0.1,fout=None,tol=1e-7,maxiter=1000):
         cp2=copy.copy(cp0)
         delta_cp2=delta_cp
         residArray2=func_resid(cp2)
@@ -461,9 +461,7 @@ class DefectEqSolver:
     def opt_Natoms(self,temperature_in,chempots_in,Natoms_target_in,
                    opt_params_in,root_outfiles,plot_params_in):
         if not "opt_Natoms_tol" in opt_params_in.keys():
-            opt_params_in["opt_Natoms_tol"]=1e-8
-        if not "opt_Natoms_1dim_tol" in opt_params_in.keys():
-            opt_params_in["opt_Natoms_1dim_tol"]=1e-10
+            opt_params_in["opt_Natoms_tol"]=1e-7
         if not "opt_Natoms_maxloop" in opt_params_in.keys():
             opt_params_in["opt_Natoms_maxloop"]=1000
         if not "opt_Natoms_output" in opt_params_in.keys():
